@@ -85,7 +85,7 @@ apply_on_ratio(int action, const torrent::Object& rawArgs) {
   if (args.empty())
     throw torrent::input_error("Too few arguments.");
 
-  torrent::Object::list_type::const_iterator argItr = args.begin();
+  torrent::Object::list_const_iterator argItr = args.begin();
 
   // first argument:  minimum ratio to reach
   // second argument: minimum upload amount to reach [optional]
@@ -97,10 +97,11 @@ apply_on_ratio(int action, const torrent::Object& rawArgs) {
   core::DownloadList* downloadList = control->core()->download_list();
 
   for  (core::Manager::DListItr itr = downloadList->begin();
-        (itr = std::find_if(itr, downloadList->end(), std::mem_fun(&core::Download::is_seeding))) != downloadList->end();
-        itr++) {
-    int64_t totalDone   = (*itr)->download()->bytes_done();
-    int64_t totalUpload = (*itr)->download()->up_rate()->total();
+        (itr = std::find_if(itr, downloadList->end(), std::mem_fun(&core::Download::is_seeding))) != downloadList->end(); ) {
+    core::Download* current = *itr++;
+
+    int64_t totalDone   = current->download()->bytes_done();
+    int64_t totalUpload = current->download()->up_rate()->total();
 
     if (!(totalUpload >= minUpload && totalUpload * 100 >= totalDone * minRatio) &&
         !(maxRatio > 0 && totalUpload * 100 > totalDone * maxRatio))
@@ -109,18 +110,18 @@ apply_on_ratio(int action, const torrent::Object& rawArgs) {
     bool success;
 
     switch (action) {
-    case core::DownloadList::SLOTS_CLOSE: success = downloadList->close_try(*itr); break;
-    case core::DownloadList::SLOTS_STOP:  success = downloadList->stop_try(*itr); break;
+    case core::DownloadList::SLOTS_CLOSE: success = downloadList->close_try(current); break;
+    case core::DownloadList::SLOTS_STOP:  success = downloadList->stop_try(current); break;
     default: success = false; break;
     }
 
     if (!success)
       continue;
 
-    rpc::call_command("d.set_ignore_commands", (int64_t)1, rpc::make_target(*itr));
+    rpc::call_command("d.set_ignore_commands", (int64_t)1, rpc::make_target(current));
 
-    for (torrent::Object::list_type::const_iterator itr2 = argItr; itr2 != args.end(); itr2++)
-      rpc::parse_command_object(rpc::make_target(*itr), *itr2);
+    for (torrent::Object::list_const_iterator itr2 = argItr; itr2 != args.end(); itr2++)
+      rpc::parse_command_object(rpc::make_target(current), *itr2);
   }
 
   return torrent::Object();
@@ -198,7 +199,7 @@ apply_schedule(const torrent::Object& rawArgs) {
   if (args.size() != 4)
     throw torrent::input_error("Wrong number of arguments.");
 
-  torrent::Object::list_type::const_iterator itr = args.begin();
+  torrent::Object::list_const_iterator itr = args.begin();
 
   const std::string& arg1 = (itr++)->as_string();
   const std::string& arg2 = (itr++)->as_string();
@@ -213,7 +214,7 @@ apply_schedule(const torrent::Object& rawArgs) {
 torrent::Object
 apply_load(int flags, const torrent::Object& rawArgs) {
   const torrent::Object::list_type&          args    = rawArgs.as_list();
-  torrent::Object::list_type::const_iterator argsItr = args.begin();
+  torrent::Object::list_const_iterator argsItr = args.begin();
 
   if (argsItr == args.end())
     throw torrent::input_error("Too few arguments.");
@@ -260,7 +261,7 @@ apply_close_low_diskspace(int64_t arg) {
 torrent::Object
 apply_download_list(const torrent::Object& rawArgs) {
   const torrent::Object::list_type&          args    = rawArgs.as_list();
-  torrent::Object::list_type::const_iterator argsItr = args.begin();
+  torrent::Object::list_const_iterator argsItr = args.begin();
 
   core::ViewManager* viewManager = control->view_manager();
   core::ViewManager::iterator viewItr;
@@ -273,7 +274,7 @@ apply_download_list(const torrent::Object& rawArgs) {
   if (viewItr == viewManager->end())
     throw torrent::input_error("Could not find view.");
 
-  torrent::Object result(torrent::Object::TYPE_LIST);
+  torrent::Object result = torrent::Object::create_list();
   torrent::Object::list_type& resultList = result.as_list();
 
   for (core::View::const_iterator itr = (*viewItr)->begin_visible(), last = (*viewItr)->end_visible(); itr != last; itr++) {
@@ -316,13 +317,13 @@ d_multicall(const torrent::Object& rawArgs) {
 
   // Add some pre-parsing of the commands, so we don't spend time
   // parsing and searching command map for every single call.
-  torrent::Object             resultRaw(torrent::Object::TYPE_LIST);
+  torrent::Object             resultRaw = torrent::Object::create_list();
   torrent::Object::list_type& result = resultRaw.as_list();
 
   for (core::View::const_iterator vItr = (*viewItr)->begin_visible(), vLast = (*viewItr)->end_visible(); vItr != vLast; vItr++) {
-    torrent::Object::list_type& row = result.insert(result.end(), torrent::Object(torrent::Object::TYPE_LIST))->as_list();
+    torrent::Object::list_type& row = result.insert(result.end(), torrent::Object::create_list())->as_list();
 
-    for (torrent::Object::list_type::const_iterator cItr = ++args.begin(), cLast = args.end(); cItr != args.end(); cItr++) {
+    for (torrent::Object::list_const_iterator cItr = ++args.begin(), cLast = args.end(); cItr != args.end(); cItr++) {
       const std::string& cmd = cItr->as_string();
       row.push_back(rpc::parse_command(rpc::make_target(*vItr), cmd.c_str(), cmd.c_str() + cmd.size()).first);
     }
