@@ -66,7 +66,7 @@ apply_view_filter(view_filter_slot viewFilterSlot, const torrent::Object& rawArg
 
   core::ViewManager::filter_args filterArgs;
 
-  for (torrent::Object::list_type::const_iterator itr = ++args.begin(), last = args.end(); itr != last; itr++)
+  for (torrent::Object::list_const_iterator itr = ++args.begin(), last = args.end(); itr != last; itr++)
     filterArgs.push_back(itr->as_string());
 
   (control->view_manager()->*viewFilterSlot)(name, filterArgs);
@@ -98,7 +98,7 @@ apply_view_sort(const torrent::Object& rawArgs) {
 
 torrent::Object
 apply_view_list(const torrent::Object&) {
-  torrent::Object rawResult(torrent::Object::TYPE_LIST);
+  torrent::Object rawResult = torrent::Object::create_list();
   torrent::Object::list_type& result = rawResult.as_list();
 
   for (core::ViewManager::const_iterator itr = control->view_manager()->begin(), last = control->view_manager()->end(); itr != last; itr++)
@@ -205,16 +205,16 @@ apply_to_xb(const torrent::Object& rawArgs) {
 // if (cond1) { branch1 } else if (cond2) { branch2 } else { branch3 }
 // <cond1>,<branch1>,<cond2>,<branch2>,<branch3>
 torrent::Object
-apply_if(rpc::target_type target, const torrent::Object& rawArgs) {
+apply_if(int flags, rpc::target_type target, const torrent::Object& rawArgs) {
   const torrent::Object::list_type& args = rawArgs.as_list();
-  torrent::Object::list_type::const_iterator itr = args.begin();
+  torrent::Object::list_const_iterator itr = args.begin();
 
   while (itr != args.end() && itr != --args.end()) {
     torrent::Object tmp;
     const torrent::Object* conditional;
 
-    if (itr->is_string() && *itr->as_string().c_str() == '$')
-      conditional = &(tmp = rpc::parse_command(target, itr->as_string().c_str() + 1, itr->as_string().c_str() + itr->as_string().size()).first);
+    if (flags & 0x1 && itr->is_string())
+      conditional = &(tmp = rpc::parse_command(target, itr->as_string().c_str(), itr->as_string().c_str() + itr->as_string().size()).first);
     else
       conditional = &*itr;
 
@@ -227,6 +227,9 @@ apply_if(rpc::target_type target, const torrent::Object& rawArgs) {
     case torrent::Object::TYPE_VALUE:
       result = conditional->as_value();
       break;
+    case torrent::Object::TYPE_NONE:
+      result = false;
+      break;
     default:
       throw torrent::input_error("Type not supported by 'if'.");
     };
@@ -242,8 +245,8 @@ apply_if(rpc::target_type target, const torrent::Object& rawArgs) {
   if (itr == args.end())
     return torrent::Object();
 
-  if (itr->is_string() && *itr->as_string().c_str() == '$')
-    return rpc::parse_command(target, itr->as_string().c_str() + 1, itr->as_string().c_str() + itr->as_string().size()).first;
+  if (flags & 0x1 && itr->is_string())
+    return rpc::parse_command(target, itr->as_string().c_str(), itr->as_string().c_str() + itr->as_string().size()).first;
   else
     return *itr;
 }
@@ -264,9 +267,15 @@ initialize_command_ui() {
 
 //   ADD_COMMAND_LIST("view_sort_current", rak::bind_ptr_fn(&apply_view_filter, &core::ViewManager::set_sort_current));
 
-  ADD_ANY_NONE("print",             rak::ptr_fn(&apply_print));
-  ADD_ANY_NONE("cat",               rak::ptr_fn(&apply_cat));
-  ADD_ANY_NONE("if",                rak::ptr_fn(&apply_if));
+  // Move.
+
+  ADD_ANY_NONE("print",                 rak::ptr_fn(&apply_print));
+  ADD_ANY_NONE("cat",                   rak::ptr_fn(&apply_cat));
+  ADD_ANY_NONE("if",                    rak::bind_ptr_fn(&apply_if, 0));
+
+  // A temporary command for handling stuff until we get proper
+  // support for seperation of commands and literals.
+  ADD_ANY_NONE("branch",                rak::bind_ptr_fn(&apply_if, 1));
 
   ADD_COMMAND_VALUE("to_date",          rak::ptr_fn(&apply_to_date));
   ADD_COMMAND_VALUE("to_time",          rak::ptr_fn(&apply_to_time));
