@@ -44,6 +44,7 @@
 #include "core/download_store.h"
 #include "core/view_manager.h"
 #include "core/scheduler.h"
+#include "core/dht_manager.h"
 
 #include "display/canvas.h"
 #include "display/window.h"
@@ -75,6 +76,7 @@ Control::Control() :
   m_core        = new core::Manager();
   m_viewManager = new core::ViewManager(m_core->download_list());
   m_scheduler   = new core::Scheduler(m_core->download_list());
+  m_dhtManager  = new core::DhtManager();
 
   m_inputStdin->slot_pressed(sigc::mem_fun(m_input, &input::Manager::pressed));
 
@@ -95,6 +97,7 @@ Control::~Control() {
   delete m_display;
   delete m_core;
   delete m_scheduler;
+  delete m_dhtManager;
 }
 
 void
@@ -120,7 +123,7 @@ Control::initialize() {
 
 void
 Control::cleanup() {
-  delete m_scgi;    m_scgi = NULL;
+  delete m_scgi; m_scgi = NULL;
   rpc::xmlrpc.cleanup();
 
   priority_queue_erase(&taskScheduler, &m_taskShutdown);
@@ -138,6 +141,13 @@ Control::cleanup() {
   display::Canvas::cleanup();
 }
 
+void
+Control::cleanup_exception() {
+  delete m_scgi; m_scgi = NULL;
+
+  display::Canvas::cleanup();
+}
+
 void
 Control::handle_shutdown() {
   if (!m_shutdownQuick) {
