@@ -55,6 +55,7 @@
 #include "globals.h"
 #include "manager.h"
 
+#include "dht_manager.h"
 #include "download.h"
 #include "download_list.h"
 #include "download_store.h"
@@ -94,6 +95,8 @@ DownloadList::clear() {
 void
 DownloadList::session_save() {
   std::for_each(begin(), end(), std::bind1st(std::mem_fun(&DownloadStore::save), control->core()->download_store()));
+
+  control->dht_manager()->save_dht_cache();
 }
 
 DownloadList::iterator
@@ -218,7 +221,7 @@ DownloadList::open_throw(Download* download) {
   if (download->download()->is_open())
     return;
   
-  download->download()->open();
+  download->download()->open(download->resume_flags());
 
   std::for_each(slot_map_open().begin(), slot_map_open().end(), download_list_call(download));
 }
@@ -253,7 +256,7 @@ DownloadList::close_try(Download* download) {
 void
 DownloadList::close_directly(Download* download) {
   if (download->download()->is_active()) {
-    download->download()->stop2(torrent::Download::stop_skip_tracker);
+    download->download()->stop(torrent::Download::stop_skip_tracker);
     torrent::resume_save_progress(*download->download(), download->download()->bencode()->get_key("libtorrent_resume"));
   }
 
@@ -269,7 +272,7 @@ DownloadList::close_quick(Download* download) {
   // handled by some parameter to the close function, or some other
   // way of giving the client more control of when STOPPED requests
   // are sent.
-  download->download()->tracker_list().manual_cancel();
+  download->download()->tracker_list()->manual_cancel();
 }
 
 void
@@ -391,6 +394,7 @@ DownloadList::resume(Download* download, int flags) {
     // open_throw(download);
 
     rpc::call_command("d.set_state_changed", cachedTime.seconds(), rpc::make_target(download));
+    rpc::call_command("d.set_state_counter", rpc::call_command_value("d.get_state_counter", rpc::make_target(download)) + 1, rpc::make_target(download));
 
     if (download->is_done()) {
       rpc::call_command("d.set_connection_current", rpc::call_command_void("d.get_connection_seed", rpc::make_target(download)), rpc::make_target(download));
@@ -404,10 +408,14 @@ DownloadList::resume(Download* download, int flags) {
       torrent::resume_save_progress(*download->download(), download->download()->bencode()->get_key("libtorrent_resume"), true);
     }
 
+    // If the DHT server is set to auto, start it now.
+    if (!download->download()->is_private())
+      control->dht_manager()->auto_start();
+
     // Update the priority to ensure it has the correct
     // seeding/unfinished modifiers.
     download->set_priority(download->priority());
-    download->download()->start2(download->resume_flags());
+    download->download()->start(download->resume_flags());
 
     download->set_resume_flags(~uint32_t());
 
@@ -438,12 +446,13 @@ DownloadList::pause(Download* download, int flags) {
     if (!download->download()->is_active())
       return;
 
-    download->download()->stop2(flags);
+    download->download()->stop(flags);
     torrent::resume_save_progress(*download->download(), download->download()->bencode()->get_key("libtorrent_resume"));
     
     std::for_each(slot_map_stop().begin(), slot_map_stop().end(), download_list_call(download));
 
     rpc::call_command("d.set_state_changed", cachedTime.seconds(), rpc::make_target(download));
+    rpc::call_command("d.set_state_counter", rpc::call_command_value("d.get_state_counter", rpc::make_target(download)), rpc::make_target(download));
 
     // Save the state after all the slots, etc have been called so we
     // include the modifications they may make.
@@ -514,7 +523,7 @@ DownloadList::hash_done(Download* download) {
     torrent::resume_save_progress(*download->download(), download->download()->bencode()->get_key("libtorrent_resume"));
 
     if (rpc::call_command_value("d.get_state", rpc::make_target(download)) == 1)
-      resume(download);
+      resume(download, download->resume_flags());
 
     break;
 
@@ -592,11 +601,11 @@ DownloadList::confirm_finished(Download* download) {
   rpc::call_command("d.set_connection_current", rpc::call_command_void("d.get_connection_seed", rpc::make_target(download)), rpc::make_target(download));
   download->set_priority(download->priority());
 
-  if (rpc::call_command_value("d.get_min_peers", rpc::make_target(download)) == rpc::call_command_value("get_min_peers") && rpc::call_command_value("get_min_peers_seed") >= 0)
-    rpc::call_command("d.set_min_peers", rpc::call_command_void("get_min_peers_seed"), rpc::make_target(download));
+  if (rpc::call_command_value("d.get_peers_min", rpc::make_target(download)) == rpc::call_command_value("get_min_peers") && rpc::call_command_value("get_min_peers_seed") >= 0)
+    rpc::call_command("d.set_peers_min", rpc::call_command_void("get_min_peers_seed"), rpc::make_target(download));
 
-  if (rpc::call_command_value("d.get_max_peers", rpc::make_target(download)) == rpc::call_command_value("get_max_peers") && rpc::call_command_value("get_max_peers_seed") >= 0)
-    rpc::call_command("d.set_max_peers", rpc::call_command_void("get_max_peers_seed"), rpc::make_target(download));
+  if (rpc::call_command_value("d.get_peers_max", rpc::make_target(download)) == rpc::call_command_value("get_max_peers") && rpc::call_command_value("get_max_peers_seed") >= 0)
+    rpc::call_command("d.set_peers_max", rpc::call_command_void("get_max_peers_seed"), rpc::make_target(download));
 
   // Do this before the slots are called in case one of them closes
   // the download.
@@ -607,7 +616,7 @@ DownloadList::confirm_finished(Download* download) {
 
   // Send the completed request before resuming so we don't reset the
   // up/downloaded baseline.
-  download->download()->tracker_list().send_completed();
+  download->download()->tracker_list()->send_completed();
 
   std::for_each(slot_map_finished().begin(), slot_map_finished().end(), download_list_call(download));
 
@@ -615,7 +624,7 @@ DownloadList::confirm_finished(Download* download) {
     throw torrent::internal_error("DownloadList::confirm_finished(...) download->resume_flags() != ~uint32_t().");
 
   if (!download->is_active() && rpc::call_command_value("d.get_state", rpc::make_target(download)) == 1)
-    resume(download, torrent::Download::start_skip_tracker | torrent::Download::start_keep_baseline);
+    resume(download, torrent::Download::start_no_create | torrent::Download::start_skip_tracker | torrent::Download::start_keep_baseline);
 }
 
 }
