@@ -38,8 +38,8 @@
 
 #include <memory>
 #include <sstream>
-#include <sigc++/bind.h>
-#include <sigc++/hide.h>
+#include <sigc++/adaptors/bind.h>
+#include <sigc++/adaptors/hide.h>
 #include <torrent/http.h>
 
 #include "rak/functional.h"
