@@ -56,6 +56,8 @@
 #include <torrent/tracker_list.h>
 
 #include "rpc/parse_commands.h"
+#include "utils/directory.h"
+#include "utils/file_status_cache.h"
 
 #include "globals.h"
 #include "curl_get.h"
@@ -176,10 +178,10 @@ Manager::Manager() :
 
   m_pollManager(NULL) {
 
-  m_downloadStore = new DownloadStore();
-  m_downloadList = new DownloadList();
-
-  m_httpQueue = new HttpQueue();
+  m_downloadStore   = new DownloadStore();
+  m_downloadList    = new DownloadList();
+  m_fileStatusCache = new FileStatusCache();
+  m_httpQueue       = new HttpQueue();
 }
 
 Manager::~Manager() {
@@ -187,6 +189,7 @@ Manager::~Manager() {
 
   delete m_downloadStore;
   delete m_httpQueue;
+  delete m_fileStatusCache;
 }
 
 void
@@ -242,6 +245,9 @@ Manager::cleanup() {
 
   m_downloadList->clear();
 
+  // When we implement asynchronous DNS lookups, we need to cancel them
+  // here before the torrent::* objects are deleted.
+
   torrent::cleanup();
   CurlStack::global_cleanup();
 
@@ -396,6 +402,12 @@ Manager::receive_http_failed(std::string msg) {
 
 void
 Manager::try_create_download(const std::string& uri, int flags, const command_list_type& commands) {
+  // If the path was attempted loaded before, skip it.
+  if (!(flags & create_raw_data) &&
+      !is_network_uri(uri) &&
+      !file_status_cache()->insert(uri, 0))
+    return;
+
   // Adding download.
   DownloadFactory* f = new DownloadFactory(this);
 
@@ -414,6 +426,11 @@ Manager::try_create_download(const std::string& uri, int flags, const command_li
   f->commit();
 }
 
+utils::Directory
+path_expand_transform(std::string path, const utils::directory_entry& entry) {
+  return path + entry.d_name;
+}
+
 // Move this somewhere better.
 void
 path_expand(std::vector<std::string>* paths, const std::string& pattern) {
@@ -421,7 +438,7 @@ path_expand(std::vector<std::string>* paths, const std::string& pattern) {
   std::vector<utils::Directory> nextCache;
 
   rak::split_iterator_t<std::string> first = rak::split_iterator(pattern, '/');
-  rak::split_iterator_t<std::string> last = rak::split_iterator(pattern);
+  rak::split_iterator_t<std::string> last  = rak::split_iterator(pattern);
     
   if (first == last)
     return;
@@ -450,17 +467,17 @@ path_expand(std::vector<std::string>* paths, const std::string& pattern) {
     for (std::vector<utils::Directory>::iterator itr = currentCache.begin(); itr != currentCache.end(); ++itr) {
       // Only include filenames starting with '.' if the pattern
       // starts with the same.
-      itr->update(r.pattern()[0] != '.');
-      itr->erase(std::remove_if(itr->begin(), itr->end(), std::not1(r)), itr->end());
+      itr->update((r.pattern()[0] != '.') ? utils::Directory::update_hide_dot : 0);
+      itr->erase(std::remove_if(itr->begin(), itr->end(), rak::on(rak::mem_ref(&utils::directory_entry::d_name), std::not1(r))), itr->end());
 
-      std::transform(itr->begin(), itr->end(), std::back_inserter(nextCache), std::bind1st(std::plus<std::string>(), itr->get_path() + "/"));
+      std::transform(itr->begin(), itr->end(), std::back_inserter(nextCache), rak::bind1st(std::ptr_fun(&path_expand_transform), itr->path() + "/"));
     }
 
     currentCache.clear();
     currentCache.swap(nextCache);
   }
 
-  std::transform(currentCache.begin(), currentCache.end(), std::back_inserter(*paths), std::mem_fun_ref(&utils::Directory::get_path));
+  std::transform(currentCache.begin(), currentCache.end(), std::back_inserter(*paths), std::mem_fun_ref(&utils::Directory::path));
 }
 
 bool
@@ -480,14 +497,6 @@ Manager::try_create_download_expand(const std::string& uri, int flags, command_l
 
   path_expand(&paths, uri);
 
-  if (flags & create_tied)
-    for (std::vector<std::string>::iterator itr = paths.begin(); itr != paths.end(); )
-      if (std::find_if(m_downloadList->begin(), m_downloadList->end(), rak::bind1st(std::ptr_fun(&manager_equal_tied), *itr))
-          != m_downloadList->end())
-        itr = paths.erase(itr);
-      else
-        itr++;
-
   if (!paths.empty())
     for (std::vector<std::string>::iterator itr = paths.begin(); itr != paths.end(); ++itr)
       try_create_download(*itr, flags, commands);
