@@ -49,6 +49,7 @@
 #include <execinfo.h>
 #endif
 
+#include "core/dht_manager.h"
 #include "core/download.h"
 #include "core/download_factory.h"
 #include "core/download_store.h"
@@ -99,16 +100,21 @@ parse_options(Control* c, int argc, char** argv) {
 
 void
 load_session_torrents(Control* c) {
-  // Load session torrents.
-  std::list<std::string> l = c->core()->download_store()->get_formated_entries().make_list();
+  utils::Directory entries = c->core()->download_store()->get_formated_entries();
+
+  for (utils::Directory::const_iterator first = entries.begin(), last = entries.end(); first != last; ++first) {
+    // We don't really support session torrents that are links. These
+    // would be overwritten anyway on exit, and thus not really be
+    // useful.
+    if (!first->is_file())
+      continue;
 
-  for (std::list<std::string>::iterator first = l.begin(), last = l.end(); first != last; ++first) {
     core::DownloadFactory* f = new core::DownloadFactory(c->core());
 
     // Replace with session torrent flag.
     f->set_session(true);
     f->slot_finished(sigc::bind(sigc::ptr_fun(&rak::call_delete_func<core::DownloadFactory>), f));
-    f->load(*first);
+    f->load(entries.path() + first->d_name);
     f->commit();
   }
 }
@@ -230,6 +236,7 @@ main(int argc, char** argv) {
 
        "schedule = session_save,1800,1800,session_save=\n"
        "schedule = low_diskspace,5,60,close_low_diskspace=500M\n"
+       "schedule = prune_file_status,3600,86400,system.file_status_cache.prune=\n"
 
        "encryption=allow_incoming,prefer_plaintext,enable_retry\n"
     );
@@ -245,6 +252,7 @@ main(int argc, char** argv) {
 
     // Load session torrents and perform scheduled tasks to ensure
     // session torrents are loaded before arg torrents.
+    control->dht_manager()->load_dht_cache();
     load_session_torrents(control);
     rak::priority_queue_perform(&taskScheduler, cachedTime);
 
@@ -270,15 +278,10 @@ main(int argc, char** argv) {
     }
 
     control->core()->download_list()->session_save();
-
     control->cleanup();
 
   } catch (std::exception& e) {
-    display::Canvas::cleanup();
-
-    // Safe to delete here? Seem to cause problems if cleanup hasn't
-    // been called.
-    //delete control;
+    control->cleanup_exception();
 
     std::cout << "rtorrent: " << e.what() << std::endl;
     return -1;
