@@ -170,7 +170,7 @@ parse_value_nothrow(const char* src, int64_t* value, int base, int unit) {
 const char*
 parse_object(const char* first, const char* last, torrent::Object* dest, bool (*delim)(const char)) {
   if (*first == '{') {
-    *dest = torrent::Object(torrent::Object::TYPE_LIST);
+    *dest = torrent::Object::create_list();
     first = parse_list(first + 1, last, dest, &parse_is_delim_list);
     first = parse_skip_wspace(first, last);
     
@@ -216,7 +216,7 @@ parse_whole_list(const char* first, const char* last, torrent::Object* dest) {
   first = parse_skip_wspace(first, last);
 
   if (first != last && parse_is_seperator(*first)) {
-    torrent::Object tmp = torrent::Object(torrent::Object::TYPE_LIST);
+    torrent::Object tmp = torrent::Object::create_list();
     tmp.swap(*dest);
 
     dest->as_list().push_back(tmp);
@@ -235,8 +235,8 @@ convert_list_to_string(const torrent::Object& src) {
 }
 
 std::string
-convert_list_to_string(torrent::Object::list_type::const_iterator first,
-                       torrent::Object::list_type::const_iterator last) {
+convert_list_to_string(torrent::Object::list_const_iterator first,
+                       torrent::Object::list_const_iterator last) {
   std::string dest;
 
   while (first != last) {
@@ -270,8 +270,8 @@ convert_list_to_string(torrent::Object::list_type::const_iterator first,
 }
 
 std::string
-convert_list_to_command(torrent::Object::list_type::const_iterator first,
-                        torrent::Object::list_type::const_iterator last) {
+convert_list_to_command(torrent::Object::list_const_iterator first,
+                        torrent::Object::list_const_iterator last) {
   if (first == last)
     throw torrent::input_error("Too few arguments.");
 
@@ -371,11 +371,12 @@ print_object(char* first, char* last, const torrent::Object* src, int flags) {
       return first;
     }
   }
+
   case torrent::Object::TYPE_VALUE:
     return std::max(first + snprintf(first, std::distance(first, last), "%lli", src->as_value()), last);
 
   case torrent::Object::TYPE_LIST:
-    for (torrent::Object::list_type::const_iterator itr = src->as_list().begin(), itrEnd = src->as_list().end(); itr != itrEnd; itr++) {
+    for (torrent::Object::list_const_iterator itr = src->as_list().begin(), itrEnd = src->as_list().end(); itr != itrEnd; itr++) {
       first = print_object(first, last, &*itr, flags);
 
       // Don't expand tilde after the first element in the list.
@@ -384,6 +385,8 @@ print_object(char* first, char* last, const torrent::Object* src, int flags) {
 
     return first;
 
+  case torrent::Object::TYPE_NONE:
+    return first;
   default:
     throw torrent::input_error("Invalid type.");
   }
@@ -412,7 +415,7 @@ print_object_std(std::string* dest, const torrent::Object* src, int flags) {
     return;
   }
   case torrent::Object::TYPE_LIST:
-    for (torrent::Object::list_type::const_iterator itr = src->as_list().begin(), itrEnd = src->as_list().end(); itr != itrEnd; itr++) {
+    for (torrent::Object::list_const_iterator itr = src->as_list().begin(), itrEnd = src->as_list().end(); itr != itrEnd; itr++) {
       print_object_std(dest, &*itr, flags);
 
       // Don't expand tilde after the first element in the list.
@@ -421,6 +424,8 @@ print_object_std(std::string* dest, const torrent::Object* src, int flags) {
 
     return;
 
+  case torrent::Object::TYPE_NONE:
+    return;
   default:
     throw torrent::input_error("Invalid type.");
   }
