@@ -107,9 +107,9 @@ inline void            call_command_d_set_string(const char* key, core::Download
 inline void            call_command_d_set_std_string(const std::string& key, core::Download* download, const std::string& arg) { commands.call_command_d(key.c_str(), download, torrent::Object(arg)); }
 
 inline torrent::Object
-call_command_d_range(const char* key, core::Download* download, torrent::Object::list_type::const_iterator first, torrent::Object::list_type::const_iterator last) {
+call_command_d_range(const char* key, core::Download* download, torrent::Object::list_const_iterator first, torrent::Object::list_const_iterator last) {
   // Change to using range ctor.
-  torrent::Object rawArgs(torrent::Object::TYPE_LIST);
+  torrent::Object rawArgs = torrent::Object::create_list();
   torrent::Object::list_type& args = rawArgs.as_list();
   
   while (first != last)
