@@ -106,7 +106,7 @@ xmlrpc_to_object(xmlrpc_env* env, xmlrpc_value* value) {
 
   case XMLRPC_TYPE_ARRAY:
   {
-    torrent::Object result(torrent::Object::TYPE_LIST);
+    torrent::Object result = torrent::Object::create_list();
     torrent::Object::list_type& listRef = result.as_list();
 
     unsigned int last = xmlrpc_array_size(env, value);
@@ -292,7 +292,7 @@ xmlrpc_to_object_target(xmlrpc_env* env, xmlrpc_value* value, int callType, void
     torrent::Object result;
 
     if (current + 1 < last) {
-      result = torrent::Object(torrent::Object::TYPE_LIST);
+      result = torrent::Object::create_list();
       torrent::Object::list_type& listRef = result.as_list();
 
       // Move this into a helper function?
@@ -350,7 +350,7 @@ object_to_xmlrpc(xmlrpc_env* env, const torrent::Object& object) {
   {
     xmlrpc_value* result = xmlrpc_array_new(env);
     
-    for (torrent::Object::list_type::const_iterator itr = object.as_list().begin(), last = object.as_list().end(); itr != last; itr++)
+    for (torrent::Object::list_const_iterator itr = object.as_list().begin(), last = object.as_list().end(); itr != last; itr++)
       xmlrpc_array_append_item(env, result, object_to_xmlrpc(env, *itr));
 
     return result;
@@ -360,7 +360,7 @@ object_to_xmlrpc(xmlrpc_env* env, const torrent::Object& object) {
   {
     xmlrpc_value* result = xmlrpc_struct_new(env);
     
-    for (torrent::Object::map_type::const_iterator itr = object.as_map().begin(), last = object.as_map().end(); itr != last; itr++)
+    for (torrent::Object::map_const_iterator itr = object.as_map().begin(), last = object.as_map().end(); itr != last; itr++)
       xmlrpc_struct_set_value(env, result, itr->first.c_str(), object_to_xmlrpc(env, itr->second));
 
     return result;
